==> ispconfig3_billing_addon_1.1.zip: billing/interface/web/billing/lib/module.conf.php <==
<?php

$module["name"] 		= "billing";
$module["title"] 		= "top_menu_billing";
$module["template"] 	= "module.tpl.htm";
$module["startpage"] 	= "billing/billing_dashboard.php";
$module["tab_width"]    = '';

$items[] = array( 'title' 	=> "Dashboard",
				  'target' 	=> 'content',
				  'link'	=> 'billing/billing_dashboard.php');


$module["nav"][] = array(	'title'	=> 'Home',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Add Client",
				  'target' 	=> 'content',
				  'link'	=> 'client/client_edit.php');

$items[] = array( 'title' 	=> "Client list",
				  'target' 	=> 'content',
				  'link'	=> 'billing/client_list.php');


$module["nav"][] = array(	'title'	=> 'Client',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);


$items[] = array( 'title' 	=> "Drafts",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_draft_list.php');

$items[] = array( 'title' 	=> "Invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_list.php');

$items[] = array( 'title' 	=> "Proforma invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/proforma_list.php');

$items[] = array( 'title' 	=> "Refunds",
				  'target' 	=> 'content',
				  'link'	=> 'billing/refund_list.php');
				  
				  $module["nav"][] = array(	'title'	=> 'Invoice',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);



$items[] = array( 'title' 	=> "Recurring item",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_recurring_item_list.php');

$items[] = array( 'title' 	=> "Make invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/create_recurring_invoices.php');

$module["nav"][] = array(	'title'	=> 'Recurring',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Email messages",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_message_list.php');

$items[] = array( 'title' 	=> "Send invoice reminders",
				  'target' 	=> 'content',
				  'link'	=> 'billing/send_invoice_reminder.php');

$items[] = array( 'title' 	=> "Email templates",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_message_template_list.php');
				  
				  $module["nav"][] = array(	'title'	=> 'Messages',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Recurring item import",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_recurring_item_import.php');

$module["nav"][] = array(	'title'	=> 'Tools',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Item template",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_item_template_list.php');

$items[] = array( 'title' 	=> "Payment terms",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_payment_term_list.php');

$items[] = array( 'title' 	=> "Company",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_company_list.php');

$items[] = array( 'title' 	=> "Global settings",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_settings_edit.php?id=1');

				  
				  $module["nav"][] = array(	'title'	=> 'Settings',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);




?>

==> ispconfig3_billing_addon_1.3.zip: billing/interface/web/billing/lib/module.conf.php <==
<?php

$module["name"] 		= "billing";
$module["title"] 		= "top_menu_billing";
$module["template"] 	= "module.tpl.htm";
$module["startpage"] 	= "billing/billing_dashboard.php";
$module["tab_width"]    = '';

$items[] = array( 'title' 	=> "Dashboard",
				  'target' 	=> 'content',
				  'link'	=> 'billing/billing_dashboard.php');


$module["nav"][] = array(	'title'	=> 'Home',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Add Client",
				  'target' 	=> 'content',
				  'link'	=> 'client/client_edit.php');

$items[] = array( 'title' 	=> "Client list",
				  'target' 	=> 'content',
				  'link'	=> 'billing/client_list.php');


$module["nav"][] = array(	'title'	=> 'Client',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);


$items[] = array( 'title' 	=> "Drafts",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_draft_list.php');

$items[] = array( 'title' 	=> "Invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_list.php');

$items[] = array( 'title' 	=> "Proforma invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/proforma_list.php');

$items[] = array( 'title' 	=> "Refunds",
				  'target' 	=> 'content',
				  'link'	=> 'billing/refund_list.php');

$items[] = array( 'title' 	=> "Reminders",
				  'target' 	=> 'content',
				  'link'	=> 'billing/reminder_list.php');
				  
				  $module["nav"][] = array(	'title'	=> 'Invoice',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);



$items[] = array( 'title' 	=> "Recurring item",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_recurring_item_list.php');

$items[] = array( 'title' 	=> "Make invoices",
				  'target' 	=> 'content',
				  'link'	=> 'billing/create_recurring_invoices.php');

$module["nav"][] = array(	'title'	=> 'Recurring',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Email messages",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_message_list.php');

$items[] = array( 'title' 	=> "Send invoice reminders",
				  'target' 	=> 'content',
				  'link'	=> 'billing/send_invoice_reminder.php');

$items[] = array( 'title' 	=> "Email templates",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_message_template_list.php');
				  
				  $module["nav"][] = array(	'title'	=> 'Messages',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Recurring item import",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_recurring_item_import.php');

$items[] = array( 'title' 	=> "Reset invoice counters",
				  'target' 	=> 'content',
				  'link'	=> 'billing/reset_invoice_counters.php');

$module["nav"][] = array(	'title'	=> 'Tools',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);

$items[] = array( 'title' 	=> "Item template",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_item_template_list.php');

$items[] = array( 'title' 	=> "Payment terms",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_payment_term_list.php');

$items[] = array( 'title' 	=> "Company",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_company_list.php');

$items[] = array( 'title' 	=> "Global settings",
				  'target' 	=> 'content',
				  'link'	=> 'billing/invoice_settings_edit.php?id=1');

				  
				  $module["nav"][] = array(	'title'	=> 'Settings',
							'open' 	=> 1,
							'items'	=> $items);

unset($items);




?>
